==> mozilla-source-0.9.8.tar.gz: mozilla/extensions/transformiix/source/xslt/txHTMLAtomList.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is TransforMiiX XSLT processor.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2001
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Peter Van der Beken <peterv@netscape.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

TX_ATOM(headerDefaultStyle, "default-style");
TX_ATOM(media, "media");
TX_ATOM(script, "script");
TX_ATOM(src, "src");
TX_ATOM(style, "style");
TX_ATOM(table, "table");
TX_ATOM(textarea, "textarea");
TX_ATOM(title, "title");
TX_ATOM(type, "type");

==> mozilla-source-1.6.tar.gz: mozilla/extensions/transformiix/source/xslt/txHTMLAtomList.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is TransforMiiX XSLT processor.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2001
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Peter Van der Beken <peterv@netscape.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

TX_ATOM(area, "area");
TX_ATOM(base, "base");
TX_ATOM(basefont, "basefont");
TX_ATOM(br, "br");
TX_ATOM(button, "button");
TX_ATOM(checked, "checked");
TX_ATOM(col, "col");
TX_ATOM(compact, "compact");
TX_ATOM(content, "content");
TX_ATOM(declare, "declare");
TX_ATOM(defer, "defer");
TX_ATOM(dir, "dir");
TX_ATOM(disabled, "disabled");
TX_ATOM(dl, "dl");
TX_ATOM(frame, "frame");
TX_ATOM(headerDefaultStyle, "default-style");
TX_ATOM(head, "head");
TX_ATOM(hr, "hr");
TX_ATOM(href, "href");
TX_ATOM(httpEquiv, "http-equiv");
TX_ATOM(img, "img");
TX_ATOM(input, "input");
TX_ATOM(isindex, "isindex");
TX_ATOM(ismap, "ismap");
TX_ATOM(li, "li");
TX_ATOM(link, "link");
TX_ATOM(media, "media");
TX_ATOM(menu, "menu");
TX_ATOM(meta, "meta");
TX_ATOM(multiple, "multiple");
TX_ATOM(noresize, "noresize");
TX_ATOM(noshade, "noshade");
TX_ATOM(nowrap, "nowrap");
TX_ATOM(object, "object");
TX_ATOM(ol, "ol");
TX_ATOM(optgroup, "optgroup");
TX_ATOM(option, "option");
TX_ATOM(p, "p");
TX_ATOM(param, "param");
TX_ATOM(readonly, "readonly");
TX_ATOM(refresh, "refresh");
TX_ATOM(script, "script");
TX_ATOM(select, "select");
TX_ATOM(selected, "selected");
TX_ATOM(src, "src");
TX_ATOM(style, "style");
TX_ATOM(table, "table");
TX_ATOM(target, "target");
TX_ATOM(tbody, "tbody");
TX_ATOM(td, "td");
TX_ATOM(textarea, "textarea");
TX_ATOM(th, "th");
TX_ATOM(title, "title");
TX_ATOM(tr, "tr");
TX_ATOM(type, "type");
TX_ATOM(ul, "ul");
